@@ -300,10 +300,7 @@ class TronConnection(BaseClient):
 
         command_string = f"{commander} {mid} {target} {command_string}\n"
 
-        command: Command[TronConnection] = Command(
-            command_string=command_string,
-            reply_callback=callback,
-        )
+        command = Command(command_string=command_string, reply_callback=callback)
         self.running_commands[mid] = command
 
         self.transport.write(command_string.encode())
